print.clus_lme displays results of the output from clus_lme.
# S3 method for clus_lme
print(x, digits = max(3L, getOption("digits") - 3L), call = TRUE, ...)print.clus_lme returns a summary table for the estimated parameters in the cluster-effect model.
an object of class "clus_lme", a result of clus_lme call.
minimal number of significant digits, see print.default.
logical. If set to TRUE, the matched call will be printed.
further arguments passed to print method.
print.clus_lme shows a summary table for the estimated parameters in the cluster-effect model (continuous diagnostic test in three-class setting).
clus_lme